==> haskell-tasty-hspec-1.2.0.4-50.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-hspec
version:              1.2.0.4
visibility:           public
id:                   tasty-hspec-1.2.0.4-GiccLd9fMi2BSFGhujNrsa
key:                  tasty-hspec-1.2.0.4-GiccLd9fMi2BSFGhujNrsa
license:              BSD-3-Clause
maintainer:           mitchellwrosen@gmail.com
author:               Mitchell Rosen
homepage:             https://github.com/mitchellwrosen/tasty-hspec
synopsis:             Hspec support for the Tasty test framework.
description:
    This package provides a Tasty provider for Hspec test
    suites.

category:             Testing
abi:                  053d95d706a8ad5cf19213e94ab6fe06
exposed:              True
exposed-modules:      Test.Tasty.Hspec
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-hspec-1.2.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-hspec-1.2.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-hspec-1.2.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hspec
hs-libraries:         HStasty-hspec-1.2.0.4-GiccLd9fMi2BSFGhujNrsa
depends:
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L base-4.18.2.1
    hspec-2.11.4-2r49l9VEKrJ4fH7w2ReGM6
    hspec-api-2.11.4-IJhYXPLNTHzIe1897BrL5s
    hspec-core-2.11.4-1HkLPyupJ0H3VqtAEeRZWL
    tasty-1.5.2-K3PchMZYxV2JdxeMIpuhjP
    tasty-quickcheck-0.11-GbgLIo2jxE4881Fm0MURY3
    tasty-smallcheck-0.8.2-3Z2KXjReSNHB9wtecSUK7g

haddock-interfaces:   /usr/share/doc/haskell-tasty-hspec/html/tasty-hspec.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hspec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hspec-1.2.0.4-51-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-hspec
version:              1.2.0.4
visibility:           public
id:                   tasty-hspec-1.2.0.4-JVNQy4dnUnA4hRNSrCP95K
key:                  tasty-hspec-1.2.0.4-JVNQy4dnUnA4hRNSrCP95K
license:              BSD-3-Clause
maintainer:           mitchellwrosen@gmail.com
author:               Mitchell Rosen
homepage:             https://github.com/mitchellwrosen/tasty-hspec
synopsis:             Hspec support for the Tasty test framework.
description:
    This package provides a Tasty provider for Hspec test
    suites.

category:             Testing
abi:                  284c26b0007fbb4f0aa8c3d4d0fafdb0
exposed:              True
exposed-modules:      Test.Tasty.Hspec
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-hspec-1.2.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-hspec-1.2.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-hspec-1.2.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hspec
hs-libraries:         HStasty-hspec-1.2.0.4-JVNQy4dnUnA4hRNSrCP95K
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS base-4.18.2.1
    hspec-2.11.4-8QgnQwrEho14jh62SRkWei
    hspec-api-2.11.4-9yghyKpx2kBDnkTc8dVOGD
    hspec-core-2.11.4-LH4ljAyFr7833CkU966kHA
    tasty-1.5.2-C3yI3pzTEHWEDVqwlNW4dB
    tasty-quickcheck-0.11.1-JnL1zGCpTCsAWK8IQVDH0c
    tasty-smallcheck-0.8.2-FcUOvCJlD66AbMNW4olrbE

haddock-interfaces:   /usr/share/doc/haskell-tasty-hspec/html/tasty-hspec.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hspec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
